@@ -81,8 +81,8 @@ static void print_times(void)
 
 /*ARGSUSED*/
 static void sec_timer_callback(
-	XtPointer		data,		/* not used */
-	XtIntervalId		*id)		/* not used */
+	UNUSED XtPointer	data,		/* not used */
+	UNUSED XtIntervalId	*id)		/* not used */
 {
 	if (have_shell) {
 		print_times();
@@ -504,9 +504,9 @@ void create_adjust_popup(void)
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_adjust_popup();
 }
@@ -514,9 +514,9 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void guess_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	Arg				args;
 
@@ -535,7 +535,7 @@ static void guess_callback(
 
 /*ARGSUSED*/
 static void dst_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -549,9 +549,9 @@ static void dst_callback(
 
 /*ARGSUSED*/
 static void adjust_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	eval_menu_texts();
 	print_text_buttons();
