@@ -101,7 +101,7 @@ void create_cal_widgets(
 			XmVaCASCADEBUTTON, s[4], 'H',
 			NULL);
 	if ((w = XtNameToWidget(menubar, "button_4")))
-		XtVaSetValues(menubar, XmNmenuHelpWidget, w, 0);
+		XtVaSetValues(menubar, XmNmenuHelpWidget, w, 0, NULL);
 	for (n=0; n < 5; n++)
 		XmStringFree(s[n]);
 
@@ -177,7 +177,8 @@ void create_cal_widgets(
 			break;
 		w = XtCreateManagedWidget(p, xmPushButtonWidgetClass,menu,0,0);
 		XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			(XtCallbackProc)language_callback, (XtPointer)n);
+			(XtCallbackProc)language_callback,
+			(XtPointer)(size_t)n);
 	}
 
 	s[ 0] = XmStringCreateSimple(_("Today"));
