@@ -523,9 +523,9 @@ void create_config_popup(void)
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_config_popup();
 }
@@ -533,7 +533,7 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void toggle_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -554,8 +554,8 @@ static void toggle_callback(
 /*ARGSUSED*/
 static void ewarn_prog_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -569,8 +569,8 @@ static void ewarn_prog_callback(
 /*ARGSUSED*/
 static void lwarn_prog_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -584,8 +584,8 @@ static void lwarn_prog_callback(
 /*ARGSUSED*/
 static void alarm_prog_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -599,8 +599,8 @@ static void alarm_prog_callback(
 /*ARGSUSED*/
 static void mailer_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -614,8 +614,8 @@ static void mailer_callback(
 /*ARGSUSED*/
 static void timeout_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
