@@ -675,6 +675,24 @@ void create_calconfig_popup(void)
 	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"range_user");
 
+							/*-- extra times --*/
+	n = 0;
+	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w);			n++;
+	XtSetArg(args[n], XmNtopOffset,		4);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	XtSetArg(args[n], XmNset,		config.moretimecols);	n++;
+	w = XtCreateManagedWidget(_("Insert extra time columns and rows"),
+			xmToggleButtonWidgetClass,
+			form2, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			flag_callback, (XtPointer)17);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"range_user");
+
 	XtRealizeWidget(shell);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
 	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
@@ -718,7 +736,7 @@ static BOOL *flagptr[] = {
 	&config.julian, &config.weeknum, &config.fullweek, &config.colorcode_m,
 	&config.nopast, &config.weekwarn,&config.weekuser, &config.owner_only,
 	&config.week_bignotime, &config.gpsweek, &config.share_mainwin,
-	&config.insecure_script, &config.thu_week
+	&config.insecure_script, &config.thu_week, &config.moretimecols
 };
 
 /*ARGSUSED*/
