@@ -167,7 +167,7 @@ time_t parse_datestring(
 	num[0] = num[1] = num[2] = 0;
 	p = text;
 	for (nnum=0; nnum < 3; nnum++) {
-		if (*p == ' ' || *p == '\t')
+		if (!*p || *p == ' ' || *p == '\t')
 			break;
 		while (*p >= '0' && *p <= '9')
 			num[nnum] = num[nnum]*10 + *p++ - '0';
