@@ -136,7 +136,7 @@ void create_recycle_popup(void)
 	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			done_callback, (XtPointer)0);
+			done_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer)"cyc_done");
 
@@ -181,7 +181,7 @@ void create_recycle_popup(void)
 			xmToggleButtonWidgetClass,
 			form2, args, n);
 	XtAddCallback(last_toggle, XmNvalueChangedCallback, (XtCallbackProc)
-			last_callback, (XtPointer)0);
+			last_callback, (XtPointer)(size_t)0);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -230,7 +230,7 @@ void create_recycle_popup(void)
 			xmToggleButtonWidgetClass,
 			form2, args, n);
 	XtAddCallback(every_toggle, XmNvalueChangedCallback, (XtCallbackProc)
-			every_callback, (XtPointer)0);
+			every_callback, (XtPointer)(size_t)0);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -274,7 +274,7 @@ void create_recycle_popup(void)
 			xmToggleButtonWidgetClass,
 			form2, args, n);
 	XtAddCallback(yearly_toggle, XmNvalueChangedCallback, (XtCallbackProc)
-			yearly_callback, (XtPointer)0);
+			yearly_callback, (XtPointer)(size_t)0);
 	XtAddCallback(yearly_toggle, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"cyc_yearly");
 
@@ -322,7 +322,7 @@ void create_recycle_popup(void)
 	  		xmToggleButtonWidgetClass,
 			rowcol, args, n);
 	   XtAddCallback(nth_widget[day], XmNvalueChangedCallback,
-			(XtCallbackProc)nth_callback, (XtPointer)day);
+			(XtCallbackProc)nth_callback, (XtPointer)(size_t)day);
 	}
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -344,7 +344,7 @@ void create_recycle_popup(void)
 	  		xmToggleButtonWidgetClass,
 			rowcol, args, n);
 	   XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			wkday_callback, (XtPointer)d);
+			wkday_callback, (XtPointer)(size_t)d);
 	}
 
 							/*-- month days --*/
@@ -400,7 +400,7 @@ void create_recycle_popup(void)
 	   w = XtCreateManagedWidget(buf, xmToggleButtonWidgetClass,
 			rowcol, args, n);
 	   XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-	  		day_callback, (XtPointer)day);
+	  		day_callback, (XtPointer)(size_t)day);
 	}
 
 	XtPopup(shell, XtGrabNone);
