@@ -99,6 +99,7 @@ static void alert		(struct entry *, int);
 void create_error_popup		(void *, int, char *, ...);
 time_t read_last_alarm          (void);
 void update_last_alarm          (void);
+static char *expand_percent	(struct entry *, char *);
 
 char			*progname;	/* argv[0] */
 extern char		lockpath[];	/* lockfile path (from lock.c) */
@@ -134,7 +135,6 @@ int main(
 	BOOL			opt_l = TRUE;	/* TRUE if -l (watch logout) */
 	BOOL			opt_s = FALSE;	/* TRUE if -s (silent) */
 	BOOL			opt_p = FALSE;	/* TRUE if -p (missed alarms) */
-	struct utmp		*u;		/* for scanning /etc/utmp */
 	struct passwd		*pw = 0;	/* user's password entry */
 	BOOL			got_login=FALSE;/* was user ever logged in? */
 	BOOL			logged_in=TRUE;	/* found in utmp? */
@@ -270,7 +270,6 @@ int main(
 		    struct utmp	ut;
 		    int		fd;
 		    int		l;
-		    short		pid = getpid();
 
 		    fd = open("/etc/utmp", 0);
 		    if (fd >= 0) {
@@ -286,11 +285,11 @@ int main(
 			}
 			close(fd);
 		    }
-#elif defined(ULTRIX)
-		    short pid = getpid();
+#elif defined(ULTRIX) || defined(MACOSX)
 		    logged_in = TRUE;
 #else
 		    short pid = getpid();
+		    struct utmp *u;
 		    setutent();
 		    while ((u = getutent()))
 			if (u->ut_type == USER_PROCESS &&
@@ -342,8 +341,8 @@ static void alert(
 		if (config.ewarn_mail)
 			send_mail(reason, entry);
 		if (config.ewarn_exec) {
-			sprintf(cmd, config.ewarn_prog,
-					entry->note ? entry->note : "");
+			sprintf(cmd, config.ewarn_prog, entry->note ?
+				expand_percent(entry, entry->note) : "");
 			exec_program(entry, cmd, FALSE);
 		}
 		break;
@@ -354,8 +353,8 @@ static void alert(
 		if (config.lwarn_mail)
 			send_mail(reason, entry);
 		if (config.lwarn_exec) {
-			sprintf(cmd, config.lwarn_prog,
-					entry->note ? entry->note : "");
+			sprintf(cmd, config.lwarn_prog, entry->note ?
+				expand_percent(entry, entry->note) : "");
 			exec_program(entry, cmd, FALSE);
 		}
 		break;
@@ -366,14 +365,15 @@ static void alert(
 		if (config.alarm_mail && !entry->noalarm)
 			send_mail(reason, entry);
 		if (config.alarm_exec && !entry->noalarm) {
-			sprintf(cmd, config.alarm_prog,
-					entry->note ? entry->note : "");
+			sprintf(cmd, config.alarm_prog, entry->note ?
+				expand_percent(entry, entry->note) : "");
 			exec_program(entry, cmd, FALSE);
 		}
 		if (entry->script) {
 			if (!config.insecure_script &&
 						(!entry->user || !entry->id))
-				exec_program(entry, entry->script, TRUE);
+				exec_program(entry, expand_percent(entry,
+							entry->script), TRUE);
 			else
 				fprintf(stderr,
 					_("%s: ignoring insecure script"),
@@ -474,7 +474,7 @@ static char *get_message(
 	struct entry	*entry)
 {
 	if (entry->message) {
-		char *msg = entry->message;
+		char *msg = expand_percent(entry, entry->message);
 		int l = strlen(msg);
 		if (l >= 20 && msg[0] == '#' && msg[1] == '#' && msg[19]=='\n')
 			if (l > 20)
@@ -619,7 +619,7 @@ static void exec_program(
 	/* DateBk4 (a PalmPilot application) synced messages may have rather */
 	/* uninteresting messages. From Johan Vromans <jvromans@squirrel.nl> */
 	if (!(msg = get_message(entry)))
-		msg = entry->note ? entry->note : "";
+		msg = entry->note ? expand_percent(entry, entry->note) : "";
 	msgsize = strlen(msg);
 
 	if (msgsize <= PIPE_MAX ||		/* child 2, feeds child 1 */
@@ -933,9 +933,9 @@ static char *get_subject(
 #ifdef JAPAN
 		msg[len++] = ' ';
 		msg[len++] = '(';
-		sprintmime(msg+len, entry->note);
+		sprintmime(msg+len, expand_percent(entry, entry->note));
 #else
-		sprintf(msg+len, " (%.50s", entry->note);
+		sprintf(msg+len, " (%.50s", expand_percent(entry,entry->note));
 #endif
 		len = strlen(msg);
 		if (msg[len-1] == '\n')
@@ -980,7 +980,7 @@ static char *get_subtitle(
 	if (entry->note && get_message(entry)) {
 		if (*msg)
 			strcat(msg, " - ");
-		strncpy(msg+strlen(msg), entry->note, 80);
+		strncpy(msg+strlen(msg), expand_percent(entry,entry->note),80);
 	}
 	return(msg);
 }
@@ -1015,6 +1015,55 @@ static char *get_icontitle(
 }
 
 
+/*
+ * given a string, expand %X codes with strings from the entry. This is used
+ * for messages and scripts, so that they can contain times and lengths etc.
+ */
+
+static char *expand_percent(
+	struct entry	*entry,		/* entry that triggered */
+	char		*text)		/* string with %X to replace */
+{
+	static char	out[4096];	/* put result with substitutions here*/
+	char		*p, *q;		/* source and ragte copy pointers */
+
+	if (!strchr(text, '%'))		/* no '%': nothing to do */
+		return(text);
+	for (p=text, q=out; *p; p++) {
+		char *replace = 0;
+		if (*p !='%') {
+			if (q < out + sizeof(out)-1)
+				*q++ = *p;
+			continue;
+		}
+		switch(*++p) {
+		  case '%': replace = "%";				break;
+		  case 'M': replace = entry->message;			break;
+		  case 'S': replace = entry->script;			break;
+		  case 'N': replace = entry->note;			break;
+		  case 'D': replace = mkdatestring(entry->time);	break;
+		  case 'T': replace = mktimestring(entry->time, FALSE);	break;
+		  case 'L': replace = mktimestring(entry->length,TRUE);	break;
+		  case 'U': replace = getenv("USER");			break;
+		  case 'F': replace = entry->private ? "private"   :
+				      entry->user    ? entry->user
+						     : getenv("USER");	break;
+		}
+		/* got a nonempty %X expansion: append to out */
+		if (replace) {
+			int len = strlen(replace);
+			if (q + len >= out + sizeof(out)-1)
+				len = sizeof(out)-1 - (q - out);
+			if (len > 0) {
+				strncpy(q, replace, len);
+				q += len;
+			}
+		}
+	}
+	*q = 0;
+	return out;
+}
+
 
 /*--------------------------------- misc ------------------------------------*/
 /*
