@@ -262,9 +262,9 @@ static void resize_canvas(
 
 /*ARGSUSED*/
 static void prev_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	curr_day -= 86400;
 	build_day(FALSE, FALSE);
@@ -274,9 +274,9 @@ static void prev_callback(
 
 /*ARGSUSED*/
 static void next_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	curr_day += 86400;
 	build_day(FALSE, FALSE);
@@ -286,9 +286,9 @@ static void next_callback(
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -299,9 +299,9 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void edit_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	create_list_popup(mainlist, curr_day, config.day_ndays*86400,
 					0, (struct entry *)0, 0, 0);
@@ -310,9 +310,9 @@ static void edit_callback(
 
 /*ARGSUSED*/
 static void sync_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (!can_edit_appts())
 		return;
