@@ -54,14 +54,14 @@ BOOL show_except_pixmap(
  */
 
 void draw_list(
-	struct listmenu		*w)		/* draw into which menu */
+	struct listmenu	*w)		/* draw into which menu */
 {
-	register Widget		(*wp)[SC_N];	/* button widget pointer */
-	struct entry		**epp;		/* entry pointer pointer */
-	register struct entry	*ep;		/* entry pointer */
-	int			n = 0;		/* entry counter */
-	int			u;		/* user number */
-	Arg			arg;		/* for toggle/user buttons */
+	Widget		(*wp)[SC_N];	/* button widget pointer */
+	struct entry	**epp;		/* entry pointer pointer */
+	struct entry	*ep;		/* entry pointer */
+	int		n = 0;		/* entry counter */
+	int		u;		/* user number */
+	Arg		arg;		/* for toggle/user buttons */
 
 	create_entry_widgets(w, w->sublist ? w->sublist->nentries : 0);
 	wp = w->entry + 1;				/* [0] is header */
@@ -134,13 +134,13 @@ void draw_list(
  */
 
 char *mkbuttonstring(
-	struct listmenu		*lw,		/* menu the button is in */
-	int			x,		/* column and row (y >= 1) */
-	int			y)
+	struct listmenu	*lw,		/* menu the button is in */
+	int		x,		/* column and row (y >= 1) */
+	int		y)
 {
-	static char		buf[40];	/* string representation */
-	register struct entry	*ep;		/* entry pointer */
-	int			u;		/* user number */
+	static char	buf[40];	/* string representation */
+	struct entry	*ep;		/* entry pointer */
+	int		u;		/* user number */
 
 	if (edit.editing && edit.menu == lw && edit.y == y)
 		ep = &edit.entry;
@@ -187,7 +187,7 @@ char *mkbuttonstring(
 		break;
 
 	  case SC_ADVDAYS:
-		sprintf(buf, "%ld", (int)(ep->days_warn / 86400));
+		sprintf(buf, "%d", (int)(ep->days_warn / 86400));
 		return(ep->days_warn > 0 ? buf : "");
 
 	  case SC_NOTE:
@@ -203,11 +203,11 @@ char *mkbuttonstring(
  */
 
 char *mknotestring(
-	register struct entry	*ep)		/* entry pointer */
+	struct entry	*ep)		/* entry pointer */
 {
-	static char		buf[256];	/* string representation */
-	char			*note;		/* note to print */
-	int			i;		/* string index */
+	static char	buf[256];	/* string representation */
+	char		*note;		/* note to print */
+	int		i;		/* string index */
 
 	if ((note = ep->note)    == 0 &&
 	    (note = ep->message) == 0 &&
