@@ -368,7 +368,7 @@ static void create_list_widgets(
 	w->confirm = XtCreateManagedWidget(_("Confirm"),
 			xmPushButtonWidgetClass, form, args, n);
 	XtAddCallback(w->confirm, XmNactivateCallback, (XtCallbackProc)
-			list_confirm, (XtPointer)0);
+			list_confirm, (XtPointer)(size_t)0);
 	XtAddCallback(w->confirm, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"day_confirm");
 
@@ -383,7 +383,7 @@ static void create_list_widgets(
 	w->undo = XtCreateManagedWidget(_("Undo"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w->undo, XmNactivateCallback, (XtCallbackProc)
-			list_undo, (XtPointer)0);
+			list_undo, (XtPointer)(size_t)0);
 	XtAddCallback(w->undo, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"day_undo");
 
@@ -398,7 +398,7 @@ static void create_list_widgets(
 	w->dup = XtCreateManagedWidget(_("Dup"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w->dup, XmNactivateCallback, (XtCallbackProc)
-			list_dup, (XtPointer)0);
+			list_dup, (XtPointer)(size_t)0);
 	XtAddCallback(w->dup, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer)"day_dup");
 
@@ -413,7 +413,7 @@ static void create_list_widgets(
 	w->del = XtCreateManagedWidget(_("Delete"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w->del, XmNactivateCallback, (XtCallbackProc)
-			list_delete, (XtPointer)0);
+			list_delete, (XtPointer)(size_t)0);
 	XtAddCallback(w->del, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer)"day_del");
 
@@ -441,7 +441,7 @@ static void create_list_widgets(
 	w->done = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w->done, XmNactivateCallback, (XtCallbackProc)
-			list_done, (XtPointer)0);
+			list_done, (XtPointer)(size_t)0);
 	XtAddCallback(w->done, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer)"day_done");
 
@@ -454,7 +454,7 @@ static void create_list_widgets(
 	w->pin = XtCreateManagedWidget(_("Pin"), xmToggleButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w->pin, XmNvalueChangedCallback, (XtCallbackProc)
-			list_pin, (XtPointer)0);
+			list_pin, (XtPointer)(size_t)0);
 	XtAddCallback(w->pin, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"day_pin");
 
@@ -469,7 +469,7 @@ static void create_list_widgets(
 	w->own = XtCreateManagedWidget(_("Own Only"),
 			xmToggleButtonWidgetClass, form, args, n);
 	XtAddCallback(w->own, XmNvalueChangedCallback, (XtCallbackProc)
-			list_own, (XtPointer)0);
+			list_own, (XtPointer)(size_t)0);
 	XtAddCallback(w->own, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"day_own");
 
@@ -655,16 +655,16 @@ void create_entry_widgets(
 		if (x < SC_L) {
 		    if (y && x)
 			XtAddCallback(w->entry[y][x], XmNactivateCallback,
-						(XtCallbackProc)list_entry,
-						(XtPointer)(x + y * SC_N));
+					(XtCallbackProc)list_entry,
+					(XtPointer)(size_t)(x + y * SC_N));
 		    if (y && !x)
 			XtAddCallback(w->entry[y][x], XmNvalueChangedCallback,
-						(XtCallbackProc)list_entry,
-						(XtPointer)(x + y * SC_N));
+					(XtCallbackProc)list_entry,
+					(XtPointer)(size_t)(x + y * SC_N));
 		}
 		XtAddCallback(w->entry[y][x], XmNhelpCallback,
-						(XtCallbackProc)help_callback,
-						(XtPointer)help_name[x]);
+					(XtCallbackProc)help_callback,
+					(XtPointer)help_name[x]);
 	    }
 	}
 	w->nentries = nentries;
@@ -821,6 +821,8 @@ void edit_list_button(
 	char		*text = "";
 	char		*space;
 	static BOOL	busy;		/* not re-entrant */
+	/* first click sets position in text widget, second selects all */
+	XmTextScanType	scantype[2] = {XmSELECT_POSITION, XmSELECT_ALL};
 
 	if (busy || !w)				/* not editing */
 		return;
@@ -850,9 +852,11 @@ void edit_list_button(
 	XtSetArg(args[n], XmNheight,		height);	n++;
 	XtSetArg(args[n], XmNrecomputeSize,	False);		n++;
 	XtSetArg(args[n], XmNpendingDelete,	True);		n++;
-	XtSetArg(args[n], XmNhighlightThickness,0);		n++;
-	XtSetArg(args[n], XmNshadowThickness,	1);		n++;
-	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
+	XtSetArg(args[n], XmNselectionArray,	scantype);	n++;
+	XtSetArg(args[n], XmNselectionArrayCount, 2);		n++;
+	XtSetArg(args[n], XmNhighlightThickness,  0);		n++;
+	XtSetArg(args[n], XmNshadowThickness,	  1);		n++;
+	XtSetArg(args[n], XmNbackground, color[COL_TEXTBACK]);	n++;
 	w->text = XtCreateManagedWidget("text", xmTextWidgetClass,
 			w->list, args, n);
 	XtAddCallback(w->text, XmNactivateCallback, (XtCallbackProc)
