@@ -213,7 +213,7 @@ void create_except_popup(void)
 	   text_w[i] = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
 			line, args, n);
 	   XtAddCallback(text_w[i], XmNactivateCallback, (XtCallbackProc)
-	   		text_callback, (XtPointer)i);
+	   		text_callback, (XtPointer)(size_t)i);
 	   n = 0;
 	   XtSetArg(args[n], XmNtopAttachment,	   XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNbottomAttachment,  XmATTACH_FORM);	n++;
@@ -224,7 +224,7 @@ void create_except_popup(void)
 	   w = XtCreateManagedWidget(_("Split"), xmPushButtonWidgetClass,
 			line, args, n);
 	   XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-	   		split_callback, (XtPointer)i);
+	   		split_callback, (XtPointer)(size_t)i);
 	   XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
 	   		help_callback, (XtPointer)"exc_split");
 	   n = 0;
@@ -238,7 +238,7 @@ void create_except_popup(void)
 	   w = XtCreateManagedWidget(_("Clear"), xmPushButtonWidgetClass,
 			line, args, n);
 	   XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-	   		clear_callback, (XtPointer)i);
+	   		clear_callback, (XtPointer)(size_t)i);
 	   XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
 	   		help_callback, (XtPointer)"exc_clear");
 
@@ -287,7 +287,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Don't show appointment in month view"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			hide_m_callback, (XtPointer)0);
+			hide_m_callback, (XtPointer)(size_t)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -299,7 +299,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Don't show appointment in year view"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			hide_y_callback, (XtPointer)0);
+			hide_y_callback, (XtPointer)(size_t)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -311,7 +311,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Don't show appointment in week view"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			hide_w_callback, (XtPointer)0);
+			hide_w_callback, (XtPointer)(size_t)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -323,7 +323,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Don't show appointment in day view"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			hide_d_callback, (XtPointer)0);
+			hide_d_callback, (XtPointer)(size_t)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -335,7 +335,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Don't show appointment in year overview"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			hide_o_callback, (XtPointer)0);
+			hide_o_callback, (XtPointer)(size_t)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -347,7 +347,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Reminder only: no alarms, time not shown"),
 			xmToggleButtonWidgetClass, form2, args, n);
 	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
-			notime_callback, (XtPointer)0);
+			notime_callback, (XtPointer)(size_t)0);
 
 							/*-- appt colors --*/
 #ifdef XmCSimpleOptionMenu
@@ -361,7 +361,8 @@ void create_except_popup(void)
 		acol_sw[i] = XtCreateManagedWidget(name,
 				xmPushButtonWidgetClass, popup, args, 2);
 		XtAddCallback(acol_sw[i], XmNactivateCallback,
-				(XtCallbackProc)acol_callback, (XtPointer)i);
+				(XtCallbackProc)acol_callback,
+				(XtPointer)(size_t)i);
 	}
 	str = XmStringCreateSimple(_("Appointment text color:"));
 	n = 0;
@@ -409,7 +410,7 @@ void create_except_popup(void)
 	acol_w = XtCreateManagedWidget(" ", xmPushButtonWidgetClass,
 			line, args, n);
 	XtAddCallback(acol_w, XmNactivateCallback, (XtCallbackProc)
-			acol_callback,(XtPointer)0);
+			acol_callback,(XtPointer)(size_t)0);
 	XtAddCallback(acol_w, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"exc_acolor");
 	n = 0;
@@ -435,7 +436,7 @@ void create_except_popup(void)
 	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			done_callback, (XtPointer)0);
+			done_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)"exc_done");
 
