@@ -233,6 +233,15 @@ static int readfile(
 	for (;;) {
 		if (!fgets(line, 1024, fp))
 			break;
+		if (!lineno && !strncasecmp(line, "begin:vcalendar", 15)) {
+			struct user *up = &user[u];
+			if (!u)
+				create_error_popup(0, 0, _("The first file in the file list\n(%s)\nmust not be a vCalendar file!\nTrying to continue, you may lose data."), path);
+			up->vcalendar = TRUE;
+			up->readonly  = TRUE;
+			read_vcal_file(list, fp, u);
+			break;
+		}
 		if (!lineno++ && !strncmp(line, "grok", 4)) {
 #ifndef PLANGROK
 			create_error_popup(0, 0,
@@ -327,7 +336,16 @@ void parse_file_line(
 		break;
 
 	  case 'o':
-		c->week_ndays  = 7;
+		tmp[0] = tmp[1] = tmp[2] = tmp[3] = tmp[4] = 0;
+		tmp[5] = 7;
+		sscanf(line+16, "%d %d %d %d %d %d",
+				 tmp+0, tmp+1, tmp+2, tmp+3, tmp+4, tmp+5);
+		c->early_time	  = tmp[0];
+		c->late_time	  = tmp[1];
+		c->wintimeout	  = tmp[2];
+		c->week_minhour	  = tmp[3];
+		c->week_maxhour	  = tmp[4];
+		c->week_ndays	  = tmp[5];
 		c->sunday_first   = line[2]  != '-';
 		c->ampm           = line[3]  != '-';
 		c->mmddyy         = line[4]  != '-';
@@ -344,13 +362,6 @@ void parse_file_line(
 		c->thu_week       = line[13] == 't';
 		c->colorcode_m    = line[14] != '-';
 		c->ownonly	  = line[15] != '-';
-		sscanf(line+16, "%d %d %d %d %d %d",
-					(int *)&c->early_time,
-					(int *)&c->late_time,
-					(int *)&c->wintimeout,
-					(int *)&c->week_minhour,
-					(int *)&c->week_maxhour,
-					(int *)&c->week_ndays);
 		if (c->week_minhour >= c->week_maxhour) {
 			c->week_minhour = 8;
 			c->week_maxhour = 20;
@@ -364,15 +375,18 @@ void parse_file_line(
 	  case 'O':
 		c->share_mainwin  = line[2]  != '-';
 		c->resize_mainwin = line[3]  != '-';
+		c->moretimecols   = line[4]  != '-';
 		break;
 
 	  case 't':
+		tmp[0] = tmp[1] = tmp[2] = tmp[3] = tmp[4] = 0;
 		sscanf(line+2, "%d %d %d %d %d",
-					(int *)&c->adjust_time,
-					(int *)&c->raw_tzone,
-					(int *)&c->dst_flag,
-					(int *)&c->dst_begin,
-					(int *)&c->dst_end);
+				 tmp+0, tmp+1, tmp+2, tmp+3, tmp+4);
+		c->adjust_time	= tmp[0];
+		c->raw_tzone	= tmp[1];
+		c->dst_flag	= tmp[2];
+		c->dst_begin	= tmp[3];
+		c->dst_end	= tmp[4];
 		set_tzone();
 		break;
 
@@ -554,12 +568,14 @@ void parse_file_line(
 		break;
 
 	  case 'R':
+		tmp[0] = tmp[1] = tmp[2] = tmp[3] = tmp[4] = 0;
 		sscanf(line+2, "%d %d %d %d %d",
-			(int *)&ep->rep_every,
-			(int *)&ep->rep_last,
-			(int *)&ep->rep_weekdays,
-			(int *)&ep->rep_days,
-			(int *)&ep->rep_yearly);
+				 tmp+0, tmp+1, tmp+2, tmp+3, tmp+4);
+		ep->rep_every	= tmp[0];
+		ep->rep_last	= tmp[1];
+		ep->rep_weekdays= tmp[2];
+		ep->rep_days	= tmp[3];
+		ep->rep_yearly	= tmp[4];
 
 		if (ep->time && ep->rep_last && ep->time > ep->rep_last)
 			ep->rep_last = 0;
