@@ -27,6 +27,7 @@
 #include "proto.h"
 #endif
 #ifdef PLANGROK
+#include "config.h"
 #include "cal.h"
 #endif
 #if defined(GROK) || defined(PLANGROK)
@@ -38,8 +39,8 @@
 #define YSNAP(y)	((y)-(y)%form->yg)
 
 #ifndef GROK
-void clone_chart_component(to, from) CHART *to, *from; {}
-void del_chart_component(item) ITEM *item; {}
+void clone_chart_component(UNUSED CHART *to, UNUSED CHART *from) {}
+void del_chart_component(UNUSED ITEM *item) {}
 extern ITEM *item_clone(ITEM *);
 extern void item_delete(FORM *, int);
 #endif
@@ -382,8 +383,8 @@ static int icompare(
 	MYCONST void	*u,
 	MYCONST void	*v)
 {
-	register ITEM	*iu = *(ITEM **)u;
-	register ITEM	*iv = *(ITEM **)v;
+	ITEM		*iu = *(ITEM **)u;
+	ITEM		*iv = *(ITEM **)v;
 
 	return(iu->y+iu->ys == iv->y+iv->ys ? iu->x+iu->xs - iv->x-iv->xs
 					    : iu->y+iu->ys - iv->y-iv->ys);
@@ -391,7 +392,7 @@ static int icompare(
 
 
 void form_sort(
-	register FORM	*form)		/* form to sort */
+	FORM		*form)		/* form to sort */
 {
 	if (!form || !form->items || !form->nitems)
 		return;
@@ -410,9 +411,9 @@ void form_sort(
 
 #ifdef GROK
 void item_deselect(
-	register FORM	*form)		/* describes form and all items in it*/
+	FORM		*form)		/* describes form and all items in it*/
 {
-	register ITEM	*item;		/* new item struct */
+	ITEM		*item;		/* new item struct */
 	int		i;		/* index of item */
 
 	for (i=0; i < form->nitems; i++) {
@@ -436,12 +437,12 @@ void item_deselect(
  */
 
 BOOL item_create(
-	register FORM	*form,		/* describes form and all items in it*/
+	FORM		*form,		/* describes form and all items in it*/
 	int		nitem)		/* the current item, insert point */
 {
-	register ITEM	*item;		/* new item struct */
-	register ITEM	*prev;		/* prev item, plundered for defaults */
-	register int	i, j, n, t;	/* various counters */
+	ITEM		*item;		/* new item struct */
+	ITEM		*prev;		/* prev item, plundered for defaults */
+	int		i, j, n, t;	/* various counters */
 	char		buf[80];	/* temp for default strings */
 
 							/* allocate array */
@@ -556,7 +557,7 @@ void item_delete(
 	FORM		*form,		/* describes form and all items in it*/
 	int		nitem)		/* the current item, insert point */
 {
-	register ITEM	*item = form->items[nitem];
+	ITEM		*item = form->items[nitem];
 	int		i;
 
 	if (item->name)		free((void *)item->name);
@@ -597,9 +598,9 @@ void item_delete(
  */
 
 ITEM *item_clone(
-	register ITEM	*parent)	/* item to clone */
+	ITEM		*parent)	/* item to clone */
 {
-	register ITEM	*item;		/* target item */
+	ITEM		*item;		/* target item */
 	int		i;
 
 	if (!(item = (ITEM *)malloc(sizeof(ITEM)))) {
