@@ -17,11 +17,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-#ifndef NEWSOS4
-#ifndef STDLIBMALLOC
+#if !defined NEWSOS4 && !defined STDLIBMALLOC && !defined MACOSX
 #include <malloc.h>
 #endif
-#endif
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
 #include <Xm/Form.h>
