@@ -20,11 +20,9 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
-#ifndef NEWSOS4
-#ifndef STDLIBMALLOC
+#if !defined NEWSOS4 && !defined STDLIBMALLOC && !defined MACOSX
 #include <malloc.h>
 #endif
-#endif
 #ifdef CPP_PATH
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -52,7 +50,7 @@ static int calc_pascha(int);
 extern int yyparse(void);
 
 
-#if defined(bsdi)||defined(linux)||defined(__NetBSD__)||defined(__FreeBSD__)||defined(HPGCC)||defined(__EMX__)||defined(__OpenBSD__)
+#if defined(bsdi)||defined(linux)||defined(__NetBSD__)||defined(__FreeBSD__)||defined(HPGCC)||defined(__EMX__)||defined(__OpenBSD__)||defined(MACOSX)
 int yylineno;
 #else
 extern int	 yylineno;		/* current line # being parsed */
