@@ -57,7 +57,7 @@ void destroy_holiday_popup(void)
 				perror(HOLIDAY_PATH);
 			XtFree(string);
 			fclose(fp);
-			if (errmsg = parse_holidays(-1, TRUE))
+			if ((errmsg = parse_holidays(-1, TRUE)))
 				create_error_popup(mainmenu.cal, 0, errmsg);
 			update_all_listmenus(TRUE);
 			redraw_all_views();
@@ -160,12 +160,12 @@ void create_holiday_popup(void)
 	XtSetArg(args[n], XmNpendingDelete,	True);			n++;
 	text = XmCreateScrolledText(form, "holiday", args, n);
 
-	if (fp = fopen(resolve_tilde(HOLIDAY_PATH), "r")) {
+	if ((fp = fopen(resolve_tilde(HOLIDAY_PATH), "r"))) {
 		fseek(fp, 0, 2);
-		if (n = ftell(fp)) {
+		if ((n = ftell(fp))) {
 			char *buf;
 			rewind(fp);
-			if (buf = malloc(n+1)) {
+			if ((buf = malloc(n+1))) {
 				if (fread(buf, n, 1, fp) == 1) {
 					buf[n] = 0;
 					XmTextSetString(text, buf);
@@ -192,18 +192,18 @@ void create_holiday_popup(void)
 /*-------------------------------------------------- callbacks --------------*/
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_holiday_popup();
 }
 
 /*ARGSUSED*/
 static void cancel_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	XtPopdown(shell);
 	XTDESTROYWIDGET(shell);
