@@ -138,9 +138,10 @@ static char **read_language_file(
 	if (!nstrings)
 		nstrings = nline;
 							/* create list */
-	if (!(list = (char **)malloc(nline * sizeof(char *) + fsize)))
+	if (!(list = (char **)malloc(nline * sizeof(char *) + fsize+1)))
 		fatal("no memory for language file");
 	memcpy(list[0] = p = (char *)&list[nline], file, fsize);
+	p[fsize] = 0;
 							/* eval "\n", eoln=0 */
 	for (q=p; *p; p++, q++)
 		if      (*p   == '\n')	*q = 0;
