@@ -371,6 +371,10 @@ static void non_interactive(
 		  case 'r':
 			edit.entry.rep_every = atoi(argv[i+1]) * 86400;
 			break;
+		  case 'Y':
+			edit.entry.rep_yearly = TRUE; 
+			--i;			/* No argument used for -Y */
+			break;
 		  case 'd':
 			edit.entry.rep_days |= 1 << atoi(argv[i+1]);
 			break;
@@ -627,7 +631,7 @@ static void usage(void)
 	    "\t-b\t\tdo fork on startup\n",
 	    "\t-k\t\tignore lock file and start up in any case\n");
 	fprintf(stderr,
-	    "append usage: %s %s%s%s%s%s%s%s%s%s%s%s%s%s%s%s\n", progname,
+	    "append usage: %s %s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s\n", progname,
 	    "[mmdd]hhmm [options] [message]*\n",
 	    "\tAdd appointment at mm/dd hh:mm (default is today).\n",
 	    "\tOptions:\n",
@@ -638,6 +642,7 @@ static void usage(void)
 	    "\t-r N\t\trepeat every N days\n",
 	    "\t-d N\t\trepeat every day N (1..31) of the month\n",
 	    "\t-D N\t\trepeat every weekday N: 0=mon, 1=tue, ... 6=sun\n",
+	    "\t-Y\t\trepeat every year (birthdays etc.)\n",
 	    "\t-e D\t\tend date, stop repeating on date D\n",
 	    "\t-w N\t\tearly warning is N minutes before hhmm time\n",
 	    "\t-W N\t\tlate warning is N minutes before hhmm time\n",
@@ -700,13 +705,14 @@ void exit(
  * for getting three types of resources: res_type={XtRInt,XtRBool,XtRString}.
  */
 
-#define get_rsrc(A,B,C,D) do_get_rsrc((XtPointer)A, B, C, D)
+#define get_rsrc(A,B,C,D,E) do_get_rsrc((XtPointer)A, B, C, D, E)
 
 void do_get_rsrc(
 	XtPointer	ret,
 	char		*res_name,
 	char		*res_class_name,
-	char		*res_type)
+	char		*res_type,
+	int		minvalue)
 {
 	XtResource	res_list[1];
 
@@ -719,53 +725,61 @@ void do_get_rsrc(
 	res_list->default_addr	  = 0;
 
 	XtGetApplicationResources(toplevel, ret, res_list, 1, NULL, 0);
+
+	if (minvalue >= 0 && res_type == XtRInt && *(int *)ret < minvalue) {
+		fprintf(stderr, "plan: configuration error in X11 resources: "
+				"%s (class %s) has value %d, minimum is %d.\n"
+				"Run plan -d to see defaults.\n", res_name,
+				res_class_name, *(int *)ret, minvalue);
+		*(int *)ret = minvalue;
+	}
 }
 
 
 static void init_resources(void)
 {
-	struct config	*c = &config;
-	char		*startup_as = 0;
+    struct config	*c = &config;
+    char		*startup_as = 0;
 
-	get_rsrc(&c->calbox_xs[0],   "calBoxWidth",    "CalBoxWidth",  XtRInt);
-	get_rsrc(&c->calbox_ys[0],   "calBoxHeight",   "CalBoxHeight", XtRInt);
-	get_rsrc(&c->calbox_marg[0], "calBoxMargin",   "CalBoxMargin", XtRInt);
-	get_rsrc(&c->calbox_arrow[0],"calArrowWidth",  "CalArrowWidth",XtRInt);
-	get_rsrc(&c->calbox_xs[1],   "calBoxWidthSm",  "CalBoxWidth",  XtRInt);
-	get_rsrc(&c->calbox_ys[1],   "calBoxHeightSm", "CalBoxHeight", XtRInt);
-	get_rsrc(&c->calbox_marg[1], "calBoxMarginSm", "CalBoxMargin", XtRInt);
-	get_rsrc(&c->calbox_arrow[1],"calArrowWidthSm","CalArrowWidth",XtRInt);
-	get_rsrc(&c->notewidth,      "noteWidth",      "NoteWidth",    XtRInt);
-	get_rsrc(&c->year_margin,    "yearMargin",     "YearMargin",   XtRInt);
-	get_rsrc(&c->year_gap,	     "yearGap",        "YearGap",      XtRInt);
-	get_rsrc(&c->year_title,     "yearTitle",      "YearTitle",    XtRInt);
-	get_rsrc(&c->yearbox_xs,     "yearBoxWidth",   "YearBoxWidth", XtRInt);
-	get_rsrc(&c->yearbox_ys,     "yearBoxHeight",  "YearBoxHeight",XtRInt);
-	get_rsrc(&c->day_margin,     "dayMargin",      "dayMargin",    XtRInt);
-	get_rsrc(&c->day_gap,        "dayGap",         "dayGap",       XtRInt);
-	get_rsrc(&c->day_headline,   "dayHeadline",    "dayHeadline",  XtRInt);
-	get_rsrc(&c->day_hourwidth,  "dayHourWidth",   "dayHourWidth", XtRInt);
-	get_rsrc(&c->day_hourheight, "dayHourHeight",  "dayHourHeight",XtRInt);
-	get_rsrc(&c->day_barwidth,   "dayBarWidth",    "dayBarWidth",  XtRInt);
-	get_rsrc(&c->week_margin,    "weekMargin",     "WeekMargin",   XtRInt);
-	get_rsrc(&c->week_gap,	     "weekGap",        "WeekGap",      XtRInt);
-	get_rsrc(&c->week_daywidth,  "weekDayWidth",   "WeekDayWidth", XtRInt);
-	get_rsrc(&c->week_hourwidth, "weekHourWidth",  "WeekHourWidth",XtRInt);
-	get_rsrc(&c->week_barheight, "weekBarHeight",  "WeekBarHeight",XtRInt);
-	get_rsrc(&c->week_bargap,    "weekBarGap",     "WeekBarGap",   XtRInt);
-	get_rsrc(&c->week_maxnote,   "weekMaxNote",    "WeekMaxNote",  XtRInt);
-	get_rsrc(&c->yov_wwidth,     "yovWWidth",      "YovWWidth",    XtRInt);
-	get_rsrc(&c->yov_wheight,    "yovWHeight",     "YovWHeight",   XtRInt);
-	get_rsrc(&c->yov_daywidth,   "yovDayWidth",    "YovDayWidth",  XtRInt);
-	get_rsrc(&c->showicontime,   "showIconTime",   "ShowIconTime",XtRBool);
-	get_rsrc(&c->showicondate,   "showIconDate",   "ShowIconDate",XtRBool);
-	get_rsrc(&c->noiconclock,    "noIconClock",    "NoIconClock", XtRBool);
-	get_rsrc(&c->frame_today,    "frameToday",     "FrameToday",  XtRBool);
-	get_rsrc(&c->noicon,	     "noIcon",         "NoIcon",      XtRBool);
-	get_rsrc(&c->sgimode,        "sgiMode",        "SgiMode",     XtRBool);
-	get_rsrc(&c->nomonthshadow,  "noMonthShadow", "NoMonthShadow",XtRBool);
-	get_rsrc(&startup_as,        "startupAs",     "StartupAs",  XtRString);
-	config.smallmonth = startup_as && *startup_as == 's';
+    get_rsrc(&c->calbox_xs[0],   "calBoxWidth",    "CalBoxWidth",  XtRInt, 16);
+    get_rsrc(&c->calbox_ys[0],   "calBoxHeight",   "CalBoxHeight", XtRInt, 16);
+    get_rsrc(&c->calbox_marg[0], "calBoxMargin",   "CalBoxMargin", XtRInt, 0);
+    get_rsrc(&c->calbox_arrow[0],"calArrowWidth",  "CalArrowWidth",XtRInt, 4);
+    get_rsrc(&c->calbox_xs[1],   "calBoxWidthSm",  "CalBoxWidth",  XtRInt, 16);
+    get_rsrc(&c->calbox_ys[1],   "calBoxHeightSm", "CalBoxHeight", XtRInt, 16);
+    get_rsrc(&c->calbox_marg[1], "calBoxMarginSm", "CalBoxMargin", XtRInt, 0);
+    get_rsrc(&c->calbox_arrow[1],"calArrowWidthSm","CalArrowWidth",XtRInt, 4);
+    get_rsrc(&c->notewidth,      "noteWidth",      "NoteWidth",    XtRInt, 16);
+    get_rsrc(&c->year_margin,    "yearMargin",     "YearMargin",   XtRInt, 0);
+    get_rsrc(&c->year_gap,	 "yearGap",        "YearGap",      XtRInt, 0);
+    get_rsrc(&c->year_title,     "yearTitle",      "YearTitle",    XtRInt, 0);
+    get_rsrc(&c->yearbox_xs,     "yearBoxWidth",   "YearBoxWidth", XtRInt, 80);
+    get_rsrc(&c->yearbox_ys,     "yearBoxHeight",  "YearBoxHeight",XtRInt, 40);
+    get_rsrc(&c->day_margin,     "dayMargin",      "dayMargin",    XtRInt, 0);
+    get_rsrc(&c->day_gap,        "dayGap",         "dayGap",       XtRInt, 0);
+    get_rsrc(&c->day_headline,   "dayHeadline",    "dayHeadline",  XtRInt, 0);
+    get_rsrc(&c->day_hourwidth,  "dayHourWidth",   "dayHourWidth", XtRInt, 20);
+    get_rsrc(&c->day_hourheight, "dayHourHeight",  "dayHourHeight",XtRInt, 8);
+    get_rsrc(&c->day_barwidth,   "dayBarWidth",    "dayBarWidth",  XtRInt, 16);
+    get_rsrc(&c->week_margin,    "weekMargin",     "WeekMargin",   XtRInt, 0);
+    get_rsrc(&c->week_gap,	 "weekGap",        "WeekGap",      XtRInt, 0);
+    get_rsrc(&c->week_daywidth,  "weekDayWidth",   "WeekDayWidth", XtRInt, 16);
+    get_rsrc(&c->week_hourwidth, "weekHourWidth",  "WeekHourWidth",XtRInt, 16);
+    get_rsrc(&c->week_barheight, "weekBarHeight",  "WeekBarHeight",XtRInt, 8);
+    get_rsrc(&c->week_bargap,    "weekBarGap",     "WeekBarGap",   XtRInt, 2);
+    get_rsrc(&c->week_maxnote,   "weekMaxNote",    "WeekMaxNote",  XtRInt, 0);
+    get_rsrc(&c->yov_wwidth,     "yovWWidth",      "YovWWidth",    XtRInt, 16);
+    get_rsrc(&c->yov_wheight,    "yovWHeight",     "YovWHeight",   XtRInt, 8);
+    get_rsrc(&c->yov_daywidth,   "yovDayWidth",    "YovDayWidth",  XtRInt, 16);
+    get_rsrc(&c->showicontime,   "showIconTime",   "ShowIconTime",XtRBool, 0);
+    get_rsrc(&c->showicondate,   "showIconDate",   "ShowIconDate",XtRBool, 0);
+    get_rsrc(&c->noiconclock,    "noIconClock",    "NoIconClock", XtRBool, 0);
+    get_rsrc(&c->frame_today,    "frameToday",     "FrameToday",  XtRBool, 0);
+    get_rsrc(&c->noicon,	 "noIcon",         "NoIcon",      XtRBool, 0);
+    get_rsrc(&c->sgimode,        "sgiMode",        "SgiMode",     XtRBool, 0);
+    get_rsrc(&c->nomonthshadow,  "noMonthShadow", "NoMonthShadow",XtRBool, 0);
+    get_rsrc(&startup_as,        "startupAs",     "StartupAs",  XtRString, 0);
+    config.smallmonth = startup_as && *startup_as == 's';
 }
 
 
@@ -835,7 +849,7 @@ static void init_colors(void)
 		}
 		strcpy(class_name, n);
 		class_name[0] &= ~('a'^'A');
-		get_rsrc(&c, n, class_name, XtRString);
+		get_rsrc(&c, n, class_name, XtRString, 0);
 		if (!XParseColor(display, cmap, c, &xcolor[i]))
 			fprintf(stderr, _("%s: unknown color for %s\n"),
 							progname, n);
@@ -889,7 +903,7 @@ static void init_fonts(void)
 		}
 		strcpy(class_name, f);
 		class_name[0] &= ~('a'^'A');
-		get_rsrc(&nf, f, class_name, XtRString);
+		get_rsrc(&nf, f, class_name, XtRString, 0);
 		if (!(font[i] = XLoadQueryFont(display, nf))) {
 			fprintf(stderr, _("plan: warning: bad font for %s\n"),
 									f);
