@@ -18,10 +18,6 @@
 #include <Xm/Xm.h>
 #include "cal.h"
 
-static BOOL set_day_bkg_color();
-static void draw_day_notes();
-static int day_to_pos(), pos_to_day();
-
 static void draw_day_notes	(int);
 static BOOL set_day_bkg_color	(int);
 static int day_to_pos		(int *, int *, int);
@@ -525,6 +521,7 @@ static void draw_day_notes(
 
 	if (!othermonth) {				/* drawn entry buffer*/
 		i = (ye - y) / ys;
+		if (i < 0) i = 0;
 		if (!drawn || i > lines_per_day) {
 			if (drawn)
 				free(drawn);
