@@ -280,9 +280,9 @@ static void resize_mainwindow(
 
 /*ARGSUSED*/
 static void month_down(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (curr_month <= 0) {
 		if (curr_year <= 0)
@@ -299,9 +299,9 @@ static void month_down(
 
 /*ARGSUSED*/
 static void month_up(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (curr_month >= 11) {
 		if (curr_year >= 2037)
@@ -318,9 +318,9 @@ static void month_up(
 
 /*ARGSUSED*/
 static void year_down(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (curr_year <= 70)
 		return;
@@ -332,9 +332,9 @@ static void year_down(
 
 /*ARGSUSED*/
 static void year_up(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (curr_year >= 137)
 		return;
