@@ -316,9 +316,9 @@ int main(
 		}
 		for (c=0; c < 2; c++)				/* connect */
 			if (fd_inet[c] >= 0 && FD_ISSET(fd_inet[c], &rd)) {
-				n = sizeof(addr);
+				unsigned int len = sizeof(addr);
 				if ((fd = accept(fd_inet[c], (struct sockaddr
-							*)&addr, &n)) < 0)
+							*)&addr, &len)) < 0)
 					perror(progname);
 				FD_SET(fd, &rd0);
 				on = 1;
@@ -328,7 +328,7 @@ int main(
 				cp = &client_list[fd];
 
 				memset(cp, 0, sizeof(struct client));
-				memcpy(&cp->addr, &addr, n);
+				memcpy(&cp->addr, &addr, len);
 				cp->uid     = nobody_uid;
 				cp->gids[0] = nobody_gid;
 				cp->descr   = mystrdup(nobody);
