@@ -35,6 +35,7 @@
 #include <string.h>
 #include <time.h>
 #include <limits.h>
+#include <syslog.h>
 #ifdef IBM
 #include <sys/select.h>
 #endif
@@ -68,6 +69,11 @@ typedef struct Acl {
 	unsigned long	*ugid, *host;	/* uid/gid and host/net data */
 } Acl;
 
+extern char		*progname;	/* name of this program, argv[0] */
+extern BOOL		verbose;	/* debug mode, don't daemonize */
+extern BOOL		to_syslog;	/* print to syslog, not stderr */
+extern struct client	*client_list;	/* array of clients (entry 0 unused) */
+
 static Acl		*acl_root;	/* root of current access list */
 static char		*word;		/* current word from input stream */
 static char		*nextword;	/* next word from input (readahead) */
@@ -81,8 +87,8 @@ extern void *allocate(int n);
 extern void *reallocate(void *o, int n);
 extern void release(void *p);
 extern char *mystrdup(const char *s);
-extern void log(char *fmt, ...);
-extern char *ip_addr(register struct sockaddr_in *);
+extern void logger(char *fmt, ...);
+extern char *ip_addr(struct sockaddr_in *);
 
 
 /*
@@ -109,13 +115,20 @@ int acl_read(
 	struct passwd	*u;		/* for adding users to ACL */
 	struct group	*g;		/* for adding groups to ACL */
 	int		**ipp;
-	char		*c;
+	char		*c=0;
 	unsigned int	usr;
 
 	acl_exit();
 	if (!(fp = fopen(fname, "r"))) {
-		perror(fname);
-		fprintf(stderr, "this is ok; access control disabled.\n");
+		if (to_syslog)
+			syslog(LOG_NOTICE, "%s: cannot open ACL file %s. "
+				"This is ok; access control disabled.\n",
+				progname, fname);
+		else {
+			perror(fname);
+			fprintf(stderr,
+				"this is ok; access control disabled.\n");
+		}
 		return(FALSE);
 	}
 	while (ret && getword(fp)) {
@@ -165,49 +178,49 @@ int acl_read(
 					acl_add_data(acl, atoi(word), 0);
 			else switch(acl->mode) {
 			  case aUSER:
-				if (u = getpwnam(word))
+				if ((u = getpwnam(word)))
 					acl_add_data(acl, u->pw_uid, 0);
 				else
-					log("%s: unknown user %s, ign"
+					logger("%s: unknown user %s, ign"
 						"ored\n", fname, word);
 				break;
 
 			  case aGROUP:
-				if (g = getgrnam(word))
+				if ((g = getgrnam(word)))
 					acl_add_data(acl, g->gr_gid, 0);
 				else
-					log("%s: unknown group %s, ignored\n",
-						fname, word);
+					logger("%s: unknown group %s, ignored"
+						"\n", fname, word);
 				break;
 
 			  case aHOST:
-				if (h = gethostbyname(word)) {
+				if ((h = gethostbyname(word))) {
 				    for (ipp=(int**)h->h_addr_list; *ipp;ipp++)
 					acl_add_data(acl, 0, ntohl(**ipp));
 				} else
-					log("%s: unknown host %s, ignored\n",
-						fname, word);
+					logger("%s: unknown host %s, ignored\n"
+						,fname, word);
 				break;
 
 			  case aUSERHOST:
-			        acl->mode = aUSER; /* GU: preparing for next word */ 
+			        acl->mode = aUSER; /* GU: prep for next word */ 
 				*c++ = 0;
 				if (*word >= '0' && *word <= '9')
 					usr = atoi(word);
 				else if (!(u = getpwnam(word))) {
-					log("%s: unknown user %s, ignored\n",
-						fname, word);
+					logger("%s: unknown user %s, ignored\n"
+						,fname, word);
 					break;
 				} else
 					usr = u->pw_uid;
 				if (*c >= '0' && *c <= '9')
 					acl_add_data(acl, usr, ipaddr_atoi(c));
-				else if (h = gethostbyname(c))
+				else if ((h = gethostbyname(c)))
 				    for (ipp=(int**)h->h_addr_list; *ipp;ipp++)
 					acl_add_data(acl, usr, ntohl(**ipp));
 				else
-					log("%s: unknown host %s, ignored\n",
-						fname, word);
+					logger("%s: unknown host %s, ignored\n"
+						,fname, word);
 			}
 		}
 		if (phase == 0) {				/* name : */
@@ -223,7 +236,7 @@ int acl_read(
 
 			} else if (getword(fp) && *word != ':') {
 				ret = FALSE;
-				log("%s: no ':' after \"%s\"\n",
+				logger("%s: no ':' after \"%s\"\n",
 					fname, acl->name ? acl->name : "*");
 			} else
 				phase = 1;
@@ -278,10 +291,10 @@ static void acl_add_data(
  */
 
 #define ISBLANK(c) strchr(", \t\n\r", c)
-#define ISWORD(c) (c >= 'a' && c <= 'z' ||\
-		   c >= 'A' && c <= 'Z' ||\
-		   c >= '0' && c <= '9' ||\
-		   c == '_' || c == '.' || c == '-' || c == '@')
+#define ISWORD(c) ((c >= 'a' && c <= 'z') ||\
+		   (c >= 'A' && c <= 'Z') ||\
+		   (c >= '0' && c <= '9') ||\
+		    c == '_' || c == '.' || c == '-' || c == '@')
 
 static BOOL getword(
 	FILE		*fp)		/* file to read from */
@@ -361,6 +374,7 @@ int acl_write(
 			switch(acl->mode) {
 			  case aUSER:	  fprintf(fp, "\n\tuser");	break;
 			  case aGROUP:	  fprintf(fp, "\n\tgroup");	break;
+			  case aUSERHOST:
 			  case aHOST:	  fprintf(fp, "\n\thost");	break;
 			}
 		for (i=0; i < acl->ndata; i++)
@@ -424,7 +438,7 @@ void acl_verify(
 {
 	Acl		*acl;		/* current acl entry */
 	unsigned int	nm;		/* current netmask for <ip> */
-	int		i, j;		/* for searching data[] and gids[]*/
+	int		i=0, j;		/* for searching data[] and gids[]*/
 	BOOL		found;
 
 	*r = *w = *d = FALSE;
@@ -448,7 +462,8 @@ void acl_verify(
 			for (found=FALSE, i=0; !found && i < acl->ndata;
 								!found && i++)
 				for (j=0; j<NGROUPS_MAX && c->gids[j]>=0; j++)
-					if (found = acl->ugid[i] == c->gids[j])
+					if ((found = (int)acl->ugid[i] ==
+						     (int)c->gids[j]))
 						break;
 			break;
 
@@ -506,13 +521,10 @@ void acl_exit(void)
  * he is. Return 0 if authentication failed, or the remote user name if ok.
  */
 
-extern BOOL		verbose;	/* debug mode, don't daemonize */
-extern struct client	*client_list;	/* array of clients (entry 0 unused) */
-
 char *ident_id(
 	int		fd)		/* client ID and socket descriptor */
 {
-	register struct client *c = &client_list[fd];
+	struct client	*c = &client_list[fd];
 	char		*hostname;
 	int		port;
 
@@ -526,11 +538,11 @@ char *ident_id(
 	hostname = ip_addr(&c->addr);
 
 	if (verbose)
-		log("client %d: authenticating, connecting to identd on "
+		logger("client %d: authenticating, connecting to identd on "
 						"%.100s\n", fd, hostname);
 	if ((idfd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-		log("client %d: cannot open socket to authentication server on"
-						"%.100s\n", fd, hostname);
+		logger("client %d: cannot open socket to authentication server"
+						"on %.100s\n", fd, hostname);
 		return(0);
 	}
 	addr.sin_family = AF_INET;
@@ -538,7 +550,7 @@ char *ident_id(
 	memcpy(&addr.sin_addr, &c->addr.sin_addr, sizeof(addr.sin_addr));
 	if (connect(idfd, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
 		close(idfd);
-		log("client %d: cannot connect to authentication server on "
+		logger("client %d: cannot connect to authentication server on "
 						"%.100s\n", fd, hostname);
 		return(0);
 	}
@@ -551,20 +563,20 @@ char *ident_id(
 	write(idfd, buf, strlen(buf));
 	if ((i = read(idfd, buf, sizeof(buf)-1)) < 0) {
 		close(idfd);
-		log("client %d: authentication server on %.100s does not "
+		logger("client %d: authentication server on %.100s does not "
 						"reply\n", fd, hostname);
 		return(0);
 	}
 	close(idfd);
 	buf[i > 2 ? i-2 : 0] = 0;
 	if (verbose)
-		log("client %d: identd replied \"%.500s\"\n", fd, buf);
+		logger("client %d: identd replied \"%.500s\"\n", fd, buf);
 	if (!strstr(buf, "USERID")) {
-		log("client %d: authentication failure on %.100s, identd "
+		logger("client %d: authentication failure on %.100s, identd "
 				"replied \"%.500s\"\n", fd, hostname, buf);
 		return(0);
 	}
-	if (p = strrchr(buf, ':'))
+	if ((p = strrchr(buf, ':')))
 		while (*++p == ' ');
 	return(p ? mystrdup(p) : 0);
 }
