@@ -141,7 +141,7 @@ char *attach_to_network(void)
 		if (!user[u].fromserver || !user[u].name || !user[u].server)
 			continue;
 		uhost = user[u].server;
-		if (p = strrchr(uhost, '/'))		/* extract hostname */
+		if ((p = strrchr(uhost, '/')))		/* extract hostname */
 			uhost = p+1;
 
 		for (hp=host_list; hp; hp=hp->next)	/* already connected?*/
@@ -315,8 +315,8 @@ BOOL server_entry_op(
 	char            *hostname;      /* server's host name */
 
 	u = name_to_user(entry->user);
-	if (!entry->id && op != 'w' || !user[u].fromserver ||
-	    entry->private && (op == 'l' || op == 'w'))
+	if ((!entry->id && op != 'w') || !user[u].fromserver ||
+	    (entry->private && (op == 'l' || op == 'w')))
 		return(TRUE);
 	host = user[u].host;
 	hostname = user[u].server;
@@ -369,7 +369,7 @@ int open_and_count_rows_on_server(
 	int		uid)		/* user[] index */
 {
 	char		buf[1024];	/* command to server, reply */
-	register char	*p;		/* for preparing raw reply lines */
+	char		*p;		/* for preparing raw reply lines */
 	struct host	*host;		/* info about host and file */
 	char		*uname;		/* file name to read */
 	int		ret;		/* return code from gets_server */
@@ -439,12 +439,12 @@ void read_from_server(
 		if (!check_server_reply(ret, buf, 'r', host->name, uname))
 			return;
 		buf[1] = '@'; /* flag for parse_file_line */
-		parse_file_line(list, host->name, uname, FALSE, buf+1);
+		parse_file_line(list, host->name, uname, buf+1);
 		while (ret == 0) {
 			ret = gets_server(host->fd, buf,sizeof(buf),TRUE,TRUE);
 			if (!check_server_reply(ret, buf, 0, host->name,uname))
 				return;
-			parse_file_line(list, host->name, uname, FALSE, buf);
+			parse_file_line(list, host->name, uname, buf);
 		}
 	}
 }
@@ -465,7 +465,7 @@ static BOOL flush_server(
 	char		*msg,		/* message string to send */
 	int		num)		/* number of bytes in *msg */
 {
-	register int	n;
+	int		n;
 
 	while (num) {
 		n = write(fd, msg, num);
@@ -486,7 +486,7 @@ BOOL puts_server(
 	static char	buf[SBUFSZ+2];	/* message buffer plus space for \n */
 	static char	*endbuf;	/* next free byte in buffer */
 	static BOOL	saved_nl;	/* \n stripped off in last call? */
-	register int	n;
+	int		n;
 
 	if (!endbuf)
 		endbuf = buf;
@@ -504,7 +504,7 @@ BOOL puts_server(
 			*endbuf++ = '\n';
 			saved_nl = FALSE;
 		}
-		if (saved_nl = n && msg[n-1] == '\n')
+		if ((saved_nl = n && msg[n-1] == '\n'))
 			msg[n-1] = 0;
 
 		while (*msg) {
@@ -578,13 +578,12 @@ BOOL gets_server(
 				if (user[u].file_id == fid)
 					break;
 			uname = u == nusers ? 0 : user[u].name;
-			parse_file_line(&mainlist, host, uname, FALSE, msg+1);
+			parse_file_line(&mainlist, host, uname, msg+1);
 			while (ret == 0) {
 				ret = gets_server_line(fd, msg, num, wait);
 				if (!check_server_reply(ret,msg,0,host,uname))
 					return(0);
-				parse_file_line(&mainlist, host, uname,
-								FALSE, msg);
+				parse_file_line(&mainlist, host, uname, msg);
 			}
 			break;
 		  default:
