@@ -7,7 +7,7 @@
  * reside in the same directory as pland; pland looks at its own path
  * in argv[0] to locate notifier.
  *
- * Author: thomas@bitrot.in-berlin.de (Thomas Driemeyer)
+ * Author: thomas@bitrot.de (Thomas Driemeyer)
  */
 
 #include <stdio.h>
@@ -123,8 +123,8 @@ int main(
 		for (q=argv[i]; *q; q++)
 			n += n + *q;
 	srandom(n);
-	sprintf(geometry, "*geometry: +%d+%d",	random()*16&240,
-						random()*16&240);
+	sprintf(geometry, "*geometry: +%d+%d",	(int)(random()*16&240),
+						(int)(random()*16&240));
 	fallbacks[0] = geometry;
 #ifdef JAPAN	/* For Japanese. */
 	XtSetLanguageProc(NULL, NULL, NULL);
@@ -145,12 +145,12 @@ int main(
 	display = XtDisplay(toplevel);
 	gc = XCreateGC(display, DefaultRootWindow(display), 0, 0);
 	init_colors();
-	if (icon = XCreatePixmapFromBitmapData(display,
+	if ((icon = XCreatePixmapFromBitmapData(display,
 				DefaultRootWindow(display),
 				icon_bits, icon_width, icon_height,
 				WhitePixelOfScreen(XtScreen(toplevel)),
 				BlackPixelOfScreen(XtScreen(toplevel)),
-				DefaultDepth(display, 0)))
+				DefaultDepth(display, 0))))
 
 		XtVaSetValues(toplevel, XmNiconPixmap, icon, NULL);
 
