@@ -20,7 +20,7 @@
 #include <string.h>
 #include <stdarg.h>
 #include <sys/types.h>
-#if defined(__EMX__) || defined(LINUX)
+#if defined(__EMX__) || defined(LINUX) || defined(MACOSX)
 #include <sys/wait.h>
 #endif
 #include <Xm/Xm.h>
@@ -128,8 +128,8 @@ no action will be taken when an alarm triggers.\n\
 Please start \"%s\" in your ~/.xsession or\n\
 ~/.sgisession file, or run plan with the -S option.";
 
-void run_daemon();
-static void cancel_callback();
+void run_daemon(Widget dialog);
+static void cancel_callback(Widget dialog);
 static BOOL running;
 
 void create_nodaemon_popup(void)
@@ -206,7 +206,7 @@ void run_daemon(
 #endif
 #endif
 		detach_from_network();
-		execl(path, DAEMON_FN, 0);
+		execl(path, DAEMON_FN, (char *)0);
 	}
 	fprintf(stderr, _("%s: WARNING: can't start %s: "), progname,
 								DAEMON_FN);
