@@ -115,7 +115,7 @@ void create_print_popup(void)
 					XmNrightOffset, 8,
 					XmNleftAttachment, XmATTACH_FORM,
 					XmNleftOffset, 8,
-					NULL, 0);
+					NULL, 0, NULL);
 
 	mode_form = XtCreateManagedWidget("print_mode", xmFormWidgetClass,
 						mode_frame, NULL, 0);
@@ -156,7 +156,8 @@ void create_print_popup(void)
 		XmStringFree(s[n]);
 		sprintf(tmp, "button_%d", n);
 		if ((w = XtNameToWidget(mode_radio, tmp)) != NULL) {
-			XtVaSetValues(w, XmNselectColor, color[COL_TOGGLE], 0);
+			XtVaSetValues(w, XmNselectColor, color[COL_TOGGLE], 0,
+					NULL);
 		}
 	}
 
