@@ -18,7 +18,8 @@ extern void do_get_rsrc(		/* read resource */
 	XtPointer	ret,
 	char		*res_name,
 	char		*res_class_name,
-	char		*res_type);
+	char		*res_type,
+	int		minvalue);
 extern char *mystrdup(			/* strdup replacement for Ultrix */
 	char		*s);
 extern void exit(			/* local version of exit w/ writeback*/
@@ -153,9 +154,16 @@ extern BOOL copyfile(			/* copy one file to another */
 	char		*target);
 extern void write_mainlist(void);	/* write all modified files */
 extern int  write_one_entry(		/* write one entry to file or server */
-	int		(*callback)(),	/* function that writes line */
+	int		(*callback)(char*),	/* function that writes line */
 	struct entry	*ep);		/* list entry to write */
 
+/*---------------------------------------- vcalendar_r.c ------------*/
+
+extern void read_vcal_file(
+	struct plist	**list,		/* list to add to */
+	FILE		*fp,		/* file to read list from */
+	int		u);		/* user number */
+
 /*---------------------------------------- vcalendar_w.c ------------*/
 
 extern void write_vcal_mainlist(
@@ -618,7 +626,7 @@ extern void destroy_user_sel_popup(void);
 extern void create_user_sel_popup(
 	Widget		widget,		/* install popup near this button */
 	int		curr,		/* current user ID (default) */
-	BOOL		(*callb)());	/* function to call with new user ID */
+	BOOL		(*callb)(int));	/* function to call with new user ID */
 
 /*---------------------------------------- network.c ------------*/
 
