@@ -1,8 +1,10 @@
-#if defined LINUX || defined __FreeBSD__
+#if defined LINUX || defined __FreeBSD__ || defined MACOSX
 "*foreground:        #000000",
 #endif
 #ifdef DESKTOP
 "*background:        #b1b1b1",
+#elif MACOSX
+"*background:        #e8e8e8",
 #else
 "*background:        #a0a0a0",
 #endif
@@ -21,11 +23,17 @@
 "*colNoteOff:        #a0a0c0",
 #ifdef DESKTOP
 "*colToggle:         #c00000",
+#elif MACOSX
+"*colToggle:         #6070f0",
 #else
 "*colToggle:         #00ff00",
 #endif
 "*colRed:            #ff0000",
+#ifdef MACOSX
+"*colTextBack:       #e0e0e8",
+#else
 "*colTextBack:       #c07070",
+#endif
 "*colYearBack:       #e0e0e0",
 "*colYearBoxBack:    #d0d0d0",
 "*colYearNumber:     #000000",
