@@ -48,14 +48,14 @@ static BOOL		keymatch(char *, char *);
  */
 
 void create_sublist(
-	register struct plist	*list,		/* main list with all entries*/
-	struct listmenu		*w)		/* menu we are doing this for*/
+	struct plist	*list,		/* main list with all entries*/
+	struct listmenu	*w)		/* menu we are doing this for*/
 {
-	char			*key = w->key;	/* keyword to look for */
-	BOOL			found;		/* TRUE if lookup succeeded */
-	struct lookup		lookup;		/* result of entry lookup */
-	register struct entry	*ep;		/* next entry to check */
-	register int		i;		/* entry counter */
+	char		*key = w->key;	/* keyword to look for */
+	BOOL		found;		/* TRUE if lookup succeeded */
+	struct lookup	lookup;		/* result of entry lookup */
+	struct entry	*ep;		/* next entry to check */
+	int		i;		/* entry counter */
 
 	list->locked++;
 	destroy_sublist(w);				/* zap old list */
@@ -76,7 +76,7 @@ void create_sublist(
 		}
 	} else if (w->key) {				/*--- keywords ---*/
 		if (search_mode == 1) {
-			register char *k;
+			char *k;
 			if (!(key = mystrdup(key))) {
 				list->locked--;
 				return;
@@ -92,9 +92,9 @@ void create_sublist(
 			}
 #endif
 		for (ep=list->entry, i=0; i < list->nentries; i++, ep++)
-			if ((ep->message && keymatch(key, ep->message)	||
-			     ep->script  && keymatch(key, ep->script )	||
-			     ep->note    && keymatch(key, ep->note   )) &&
+			if (((ep->message && keymatch(key, ep->message)) ||
+			     (ep->script  && keymatch(key, ep->script )) ||
+			     (ep->note    && keymatch(key, ep->note   ))) &&
 					      (!w->own_only || !ep->user ||
 					      !strcmp(user[0].name, ep->user)))
 				append_entry(&w->sublist, ep);
@@ -119,8 +119,8 @@ void create_sublist(
 
 	} else if (w->user_plus_1) {			/*--- one file --- */
 		for (i=0; i < list->nentries; i++, ep++)
-			if (w->user_plus_1 == 1 && !ep->user ||
-			    w->user_plus_1 == name_to_user(ep->user)+1)
+			if ((w->user_plus_1 == 1 && !ep->user) ||
+			     w->user_plus_1 == name_to_user(ep->user)+1)
 				append_entry(&w->sublist, ep);
 
 	} else {					/*--- all ---*/
@@ -157,14 +157,14 @@ void destroy_sublist(
  */
 
 static BOOL keymatch(
-	char			*key,		/* keyword to look for */
-	char			*string)	/* text to look in */
+	char		*key,		/* keyword to look for */
+	char		*string)	/* text to look in */
 {
-	register char		*p;		/* fast string scan ptr */
-	register char		key0 = key[0];	/* first char of key */
-	register char		c;		/* temp for case conversion */
-	register int		i;		/* scan index */
-	register int		len = strlen(key);
+	char		*p;		/* fast string scan ptr */
+	char		key0 = key[0];	/* first char of key */
+	char		c;		/* temp for case conversion */
+	int		i;		/* scan index */
+	int		len = strlen(key);
 
 	switch(search_mode) {
 	  default:
@@ -215,14 +215,14 @@ static BOOL keymatch(
  */
 
 static void append_entry(
-	struct sublist		**sub,		/* list to append to */
-	struct entry		*entry)		/* entry to append */
+	struct sublist	**sub,		/* list to append to */
+	struct entry	*entry)		/* entry to append */
 {
-	int			num;		/* # of entries in old list */
-	int			size;		/* size of allocated old list*/
-	struct sublist		*new;		/* larger list if required */
-	register struct entry	**p, **q;	/* entry copy pointers */
-	register int		i;		/* entry copy counter */
+	int		num;		/* # of entries in old list */
+	int		size;		/* size of allocated old list*/
+	struct sublist	*new;		/* larger list if required */
+	struct entry	**p, **q;	/* entry copy pointers */
+	int		i;		/* entry copy counter */
 
 	num  = *sub ? (*sub)->nentries : 0;
 	size = *sub ? (*sub)->size     : 0;
