@@ -240,8 +240,10 @@ void guess_tzone(void)
 		time_t h = tm->tm_hour;
 		struct tm *gmt = gmtime(&now);
 		zone = gmt->tm_hour - h;
-		if (zone < -12)		/* Truxton Fulton <trux@truxton.com> */
+		if (zone < -13)
 			zone += 24;
+		if (zone > 10)
+			zone -= 24;
 		zone *= 3600;
 #else
 #if defined(bsdi) || defined(SUN) || defined(SVR4) || defined(convex)
