@@ -320,7 +320,7 @@ void create_user_popup(void)
 	delete = w = XtCreateManagedWidget(_("Delete"),
 			xmPushButtonWidgetClass, form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			delete_callback, (XtPointer)0);
+			delete_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback,   (XtPointer) "user_delete");
 	n = 0;
@@ -333,7 +333,7 @@ void create_user_popup(void)
 	w = XtCreateManagedWidget(_("Sort"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			sort_callback, (XtPointer)0);
+			sort_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer) "user_sort");
 	n = 0;
@@ -346,7 +346,7 @@ void create_user_popup(void)
 	w = XtCreateManagedWidget(_("Browse"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			browse_callback, (XtPointer)0);
+			browse_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer) "user_browse");
 	n = 0;
@@ -358,7 +358,7 @@ void create_user_popup(void)
 	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			done_callback, (XtPointer)0);
+			done_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer) "user_done");
 	n = 0;
@@ -384,7 +384,7 @@ void create_user_popup(void)
 	w = XtCreateManagedWidget(_("Cancel"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
-			cancel_callback, (XtPointer)0);
+			cancel_callback, (XtPointer)(size_t)0);
 	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
 			help_callback, (XtPointer) "user_done");
 
@@ -571,18 +571,19 @@ void create_user_rows(void)
 					urow[COLPOPUP], args, 3);
 				XtAddCallback(w, XmNactivateCallback,
 					(XtCallbackProc)list_callback,
-					(XtPointer)(C_GROUP + y * NCOLUMNS
-							    + (n+1) * 65536));
+					(XtPointer)(size_t)(C_GROUP
+							+ y * NCOLUMNS
+							+ (n+1) * 65536));
 			}
 			XtAddEventHandler(urow[x], ButtonPressMask, False,
 					(XtEventHandler)call_popup_callback,
-					(XtPointer)y);
+					(XtPointer)(size_t)y);
 		} else
 #endif
 		if (y)
 			XtAddCallback(urow[x], callbk,
 					(XtCallbackProc)list_callback,
-			   		(XtPointer)(x + y * NCOLUMNS));
+			   		(XtPointer)(size_t)(x + y * NCOLUMNS));
 		XtAddCallback(urow[x], XmNhelpCallback,
 					(XtCallbackProc)help_callback,
 					(XtPointer)cell_help[x]);
@@ -680,7 +681,7 @@ static void edit_user_button(
 	textwidget = XtCreateManagedWidget("text", xmTextWidgetClass,
 						ulist, args, n);
 	XtAddCallback(textwidget, XmNactivateCallback, (XtCallbackProc)
-			got_text, (XtPointer)(x + y * NCOLUMNS));
+			got_text, (XtPointer)(size_t)(x + y * NCOLUMNS));
 	XtAddCallback(textwidget, XmNhelpCallback, (XtCallbackProc)
 			help_callback, (XtPointer)cell_help[x]);
 	XmProcessTraversal(textwidget, XmTRAVERSE_CURRENT);
