@@ -290,6 +290,8 @@ static BOOL check_process(
 	p = p ? p+1 : buf;
 	return(!strcmp(p, pland ? "pland" : "plan"));	/* compare prog name */
 #else
+	(void)pland;
+	(void)pid;
 	return(FALSE);
 #endif
 }
