@@ -372,7 +372,7 @@ static void draw_week_day_background(
 			 week.nlines[wday] * ys);
 							/* repeated times */
 	if (wday && c->week_gap > font[FONT_WHOUR]->max_bounds.ascent-2
-		 && drawn_lines > 10) {
+		 && drawn_lines > 10 && config.moretimecols) {
 		drawn_lines -= 10;
 		g_setcolor(COL_WDAY);
 		g_setfont(FONT_WHOUR);
