@@ -259,9 +259,9 @@ static void resize_canvas(
 
 /*ARGSUSED*/
 static void prev_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	curr_week -= 7*86400;
 	build_week(FALSE, FALSE);
@@ -271,9 +271,9 @@ static void prev_callback(
 
 /*ARGSUSED*/
 static void next_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	curr_week += 7*86400;
 	build_week(FALSE, FALSE);
@@ -283,9 +283,9 @@ static void next_callback(
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -296,9 +296,9 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void edit_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	create_list_popup(mainlist, curr_week, config.week_ndays*86400,
 					0, (struct entry *)0, 0, 0);
@@ -307,9 +307,9 @@ static void edit_callback(
 
 /*ARGSUSED*/
 static void sync_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (!can_edit_appts())
 		return;
