@@ -93,7 +93,7 @@ void init_pixmaps(void)
 	BOOL			failed;
 
 	cmap = DefaultColormap(display, DefaultScreen(display));
-	do_get_rsrc((XtPointer)&c, "colBack", "ColBack", XtRString);
+	do_get_rsrc((XtPointer)&c, "colBack", "ColBack", XtRString, 0);
 	failed = !c || !XParseColor(display, cmap, c, &rgb)
 		    || !XAllocColor(display, cmap, &rgb);
 	for (p=0; p < NPICS; p++)
