@@ -8,7 +8,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#if !defined NEWSOS4 && !defined STDLIBMALLOC
+#if !defined NEWSOS4 && !defined STDLIBMALLOC && !defined MACOSX
 #include <malloc.h>
 #endif
 #include <time.h>
