@@ -65,27 +65,27 @@ static int		ndays;		/* number of days in year <curr_yov> */
  */
 
 MOUSE locate_in_yov_calendar(
-	struct entry		**epp,		/* returned entry or 0 */
-	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
-	time_t			*time,		/* if *epp=0, clicked where */
-	time_t			*trigger,	/* if *epp=0, entry trigger */
-	int			*xp,		/* if M_INSIDE, rubber box */
-	int			*yp,
-	int			*xsp,		/* position and size */
-	int			*ysp,
-	int			xc,		/* pixel pos clicked */
-	int			yc)
+	struct entry	**epp,		/* returned entry or 0 */
+	BOOL		*warn,		/* is *epp an n-days-ahead w?*/
+	time_t		*time,		/* if *epp=0, clicked where */
+	time_t		*trigger,	/* if *epp=0, entry trigger */
+	int		*xp,		/* if M_INSIDE, rubber box */
+	int		*yp,
+	int		*xsp,		/* position and size */
+	int		*ysp,
+	int		xc,		/* pixel pos clicked */
+	int		yc)
 {
-	register struct config	*c = &config;
-	struct weeknode		*vert, *horz;	/* yov node scan pointers */
-	register struct entry	*ep;		/* entry to test */
-	int			daysz;		/* horz pixels per day */
-	int			s;		/* strip counter */
-	int			yd;		/* y start coord of day box */
-	int			x, y;		/* upper left of day bk box */
-	int			xend;		/* right margin of chart */
-	int			ys;		/* height of bar line w/ gaps*/
-	int			b, e;		/* X start end end pos of bar*/
+	struct config	*c = &config;
+	struct weeknode	*vert, *horz;	/* yov node scan pointers */
+	struct entry	*ep;		/* entry to test */
+	int		daysz;		/* horz pixels per day */
+	int		s;		/* strip counter */
+	int		yd;		/* y start coord of day box */
+	int		x, y;		/* upper left of day bk box */
+	int		xend;		/* right margin of chart */
+	int		ys;		/* height of bar line w/ gaps*/
+	int		b, e;		/* X start end end pos of bar*/
 
 	x     = c->week_margin + c->week_daywidth + c->week_gap;
 	yd    = c->week_margin + 2*c->week_hour + c->week_gap + 2;
@@ -188,14 +188,14 @@ void print_yov_calendar(
 
 static void gen_yov(void)
 {
-	register struct config	*c = &config;
-	struct tm		*tm;
-	char			buf[40], *p;
-	int			year;		/* current year, 1970..2038 */
-	int			daysz;		/* horz pixels per day */
-	int			wday0;		/* weekday (0=mon) of 1st day*/
-	int			i, m, d, x, y;
-	int			charwidth;	/* width of a day num digit */
+	struct config	*c = &config;
+	struct tm	*tm;
+	char		buf[40], *p;
+	int		year;		/* current year, 1970..2038 */
+	int		daysz;		/* horz pixels per day */
+	int		wday0;		/* weekday (0=mon) of 1st day*/
+	int		i, m, d, x, y;
+	int		charwidth;	/* width of a day num digit */
 
 	tm    = time_to_tm(curr_yov);
 	year  = tm->tm_year;
@@ -203,7 +203,7 @@ static void gen_yov(void)
 	ndays = year & 3 ? 365 : 366;
 	daysz = c->yov_daywidth / c->yov_nmonths;
 	if (daysz < 1) daysz = 1;
-	if (p = parse_holidays(year, FALSE))
+	if ((p = parse_holidays(year, FALSE)))
 		create_error_popup(mainmenu.cal, 0, p);
 
 	for (i=0; i < yov_nstrips; i++)			/* strip backgrounds */
@@ -261,8 +261,10 @@ static void gen_yov(void)
 			g_fillrect(x, y+3, 1, yov.canvas_ys-c->week_margin-y);
 		}
 		x += daysz;
-		if (++d > (monthlen[m] + (m == 1 && !(year & 3))))
-			d -= monthlen[m++] + (m == 1 && !(year & 3));
+		if (++d > (monthlen[m] + (m == 1 && !(year & 3)))) {
+			d -= monthlen[m] + (m == 1 && !(year & 3));
+			m++;
+		}
 	}
 	g_fillrect(x, y+3, 1, yov.canvas_ys - c->week_margin - y);
 	for (i=0; i < yov_nstrips; i++)			/* strip foreground */
@@ -284,15 +286,15 @@ static void gen_yov(void)
  */
 
 static void draw_yov_strip_background(
-	int			strip)		/* day of the yov, < NDAYS */
+	int		strip)		/* day of the yov, < NDAYS */
 {
-	register struct config	*c = &config;
-	char			buf[64];	/* holiday/user text buffer */
-	char			*p;		/* temp for day name */
-	int			x, y;		/* upper left of day bk box */
-	int			ys;		/* height of bar line w/ gaps*/
-	int			yts;		/* vert space for text */
-	int			i;
+	struct config	*c = &config;
+	char		buf[64];	/* holiday/user text buffer */
+	char		*p;		/* temp for day name */
+	int		x, y;		/* upper left of day bk box */
+	int		ys;		/* height of bar line w/ gaps*/
+	int		yts;		/* vert space for text */
+	int		i;
 
 	if (yov.nlines[strip] == 0)
 		return;
@@ -309,7 +311,7 @@ static void draw_yov_strip_background(
 
 							/* user name */
 	i = (strip + 7 - c->sunday_first) % 7;
-	if (p = yov.tree[strip]->entry->user) {
+	if ((p = yov.tree[strip]->entry->user)) {
 		strncpy(buf, p, sizeof(buf));
 		buf[sizeof(buf)-1] = 0;
 	} else
@@ -333,13 +335,13 @@ static void draw_yov_strip_background(
  */
 
 static void draw_yov_strip_foreground(
-	int			strip)		/* user strip number, 0=top */
+	int		strip)		/* user strip number, 0=top */
 {
-	register struct config	*c = &config;
-	struct weeknode		*vert, *horz;	/* yov node scan pointers */
-	int			x, y;		/* upper left of day bk box */
-	int			ys;		/* height of bar line w/ gaps*/
-	int			i, u;
+	struct config	*c = &config;
+	struct weeknode	*vert, *horz;	/* yov node scan pointers */
+	int		x, y;		/* upper left of day bk box */
+	int		ys;		/* height of bar line w/ gaps*/
+	int		i, u;
 
 	x  = c->week_margin + c->week_daywidth + c->week_gap;
 	y  = c->week_margin + 2*c->week_hour + c->week_gap + 2;
@@ -361,22 +363,22 @@ static void draw_yov_strip_foreground(
  */
 
 static void draw_bar(
-	struct weeknode		*node,		/* entry node to print */
-	int			color,		/* color, 0..7 */
-	int			x,		/* top left pos in canvas */
-	int			y)
+	struct weeknode	*node,		/* entry node to print */
+	int		color,		/* color, 0..7 */
+	int		x,		/* top left pos in canvas */
+	int		y)
 {
-	register struct entry	*ep = node->entry;
-	register struct config	*c = &config;
-	int			xend;		/* right margin of chart */
-	int			b, e;		/* begin/end pixel position */
-	int			daysz;		/* horz pixels per day */
-	int			slope;		/* delta-x of the arrowheads */
-	XPoint			point[7];	/* polygon vertex list */
+	struct entry	*ep = node->entry;
+	struct config	*c = &config;
+	int		xend;		/* right margin of chart */
+	int		b, e;		/* begin/end pixel position */
+	int		daysz;		/* horz pixels per day */
+	int		slope;		/* delta-x of the arrowheads */
+	XPoint		point[7];	/* polygon vertex list */
 #ifdef JAPAN
-	int			plen;		/* pixel-length of partialstr */
-	strpack			partialstr[MAXPARTIALSTRING];
-	unsigned char		strpool[MAXPARTIALCHAR];
+	int		plen;		/* pixel-length of partialstr */
+	strpack		partialstr[MAXPARTIALSTRING];
+	unsigned char	strpool[MAXPARTIALCHAR];
 #endif
 
 	daysz = c->yov_daywidth / c->yov_nmonths;
